@@ -130,14 +130,18 @@ def getFeatureVector(img,rect=None):
     if not rect:
         try:
             rect=_detector(img, 1)[0] #如果沒有傳入rect取第一個檢測到的臉區域
-        except:return None
+        except:return []
     shape = _sp(img,rect) #找出特徵點位置
     #由圖片中特徵點位置(shape)擷取出特徵向量(128維特徵向量)
     face_descriptor = _facerec.compute_face_descriptor(img, shape)
     # 轉換numpy array格式
-    return numpy.array(face_descriptor)
-
+    return numpy.array(face_descriptor)     
 
+def getFaceRects(img):
+    try:
+        return _detector(img, 1)
+    except:return []
+    
 def loadImg(fname):
     '''
     loadImg(fname)
@@ -165,9 +169,11 @@ def loadDB(db=DB,folder='train',isClearDB=True):
         path = folder+"\\"+f
         if os.path.isfile(path):
             img = io.imread(path)
-            db[os.path.splitext(f)[0]]=getFeatureVector(img)
-            print(f+" feature loaded")
-
+            FV = getFeatureVector(img)
+            if len(FV)>0:
+                db[os.path.splitext(f)[0]]=getFeatureVector(img)
+                print(f+" feature loaded")
+            else:print(f+" fail to detect face!!")
 def loadFeatureFromPic(imagePath):
     '''
     loadFeatureFromPic(imagePath)
@@ -388,9 +394,29 @@ def predictVedio(vedioPath,skipFranmes=10,db=DB):
     cap.release()
     cv2.destroyAllWindows()
     
-    
+from skimage import transform
+import matplotlib.pyplot as plt
+#from skimage.util import crop
 if __name__ == "__main__":
     #captureImageFromCamAndSave('李國源',camSerial=1)
+    '''
+    img = loadImg('train/林志玲.jpg')
+    rect = getFaceRect(img)
+    print(rect)
+    faceImg = img[rect.top():rect.bottom(),rect.left():rect.right()]
+    dst=transform.downscale_local_mean(faceImg,(15,15,1))
+    dst=transform.resize(dst,(200,200),anti_aliasing=False)
+    print(numpy.shape(dst))
+    fig, axes = plt.subplots(nrows=1, ncols=2)
+    ax = axes.ravel()
+    ax[0].imshow(dst)
+    ax[1].imshow(faceImg)
+    plt.tight_layout()
+    plt.show()
+    io.imsave('test.png',dst)
+    io.imsave('test1.png',faceImg)
+    '''
+    
     '''
     #download the samples to 'train' folder
     downloadImageSamples()
